require 'spec_helper'

RSpec.describe StaticPost::Base do
  before(:each) do
    class TestPost < StaticPost::Base; end
  end

  it '#post_path returns default path' do
    expect(TestPost.post_path).to eql(File.expand_path('.'))
  end

  it '#post_path to set post path' do
    TestPost.post_path("#{__dir__}/fixtures")
    expect(TestPost.post_path).to eql("#{__dir__}/fixtures")
  end

  it '#post_path used in class' do
    class AnotherTestPost < StaticPost::Base
      post_path 'new_path'
    end
    expect(AnotherTestPost.post_path).to eql(File.expand_path('new_path'))
  end

  it '#post_files' do
    TestPost.post_path("#{__dir__}/fixtures")
    expect(TestPost.post_files).to eql(['test_doc.md'])
  end

  it '#extract_frontmatter' do
    content = "---\ntitle: Test Post\n---\nDocument Content"
    parsed_yaml = TestPost.extract_frontmatter(content)
    expect(parsed_yaml).to eql(title: 'Test Post')
  end

  it '#post_content' do
    content = "---\ntitle: Test Post\n---\nDocument Content"
    parsed_yaml = TestPost.post_content(content)
    expect(parsed_yaml).to eql("<p>Document Content</p>\n")
  end

  it '#default_post_path' do
    expect(TestPost.default_post_path).to eql(File.expand_path('.'))
  end

  it '#default_post_path with rails' do
    class App
      def root
        'test/path'
      end
    end
    Rails = App.new
    expected_path = File.expand_path('test/path/app/views/posts')
    expect(TestPost.default_post_path).to eql(expected_path)
  end
end
